# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [v1.1.0]

### Added 

- Support Python 3.8, 3.9, 3.10
- Updated journal reference.
- Added Package logo.
- Renamed test scripts to ease pytest's discovery.
- Cleaned up test suite.
- Simplified test workflows.
- Removed `text.usetex` from examples.
- Removed `versioneer` in favour of `setuptools_scm`.
- Added `logging` module.
- Use `pyproject.toml` keeping a minimal `setup.py` for local installs.

### Fixed
